@@ -6,6 +6,21 @@ test_that("we can read a shapefile using st_read", {
   expect_equal(dim(nc), c(100, 15))
 })
 
+test_that("we can read shapefiles with a query string", {
+    nc <- st_read(system.file("shape/nc.shp", package="sf"), "nc", crs = 4267, quiet = TRUE)
+    nc_all <- st_read(system.file("shape/nc.shp", package="sf"), "nc", query = "select * from nc", crs = 4267, quiet = TRUE)
+    nc_some <- st_read(system.file("shape/nc.shp", package="sf"), "nc", query = "select * from nc where SID79 > 50", crs = 4267, quiet = TRUE)
+})
+
+test_that("st_read.default gives error messages", {
+  expect_error(st_read(), "dsn should specify a data source or filename")
+  expect_error(st_read(NULL), "no st_read method available for objects of class NULL")
+})
+
+test_that("st_write.sf gives error messages on unknown dsn", {
+  expect_error(st_write(st_sf(st_sfc(st_point())), NULL), "no st_write method available for dsn of class NULL")
+})
+
 test_that("stringsAsFactors = FALSE produces a data.frame with no factors", {
   nc <-  st_read(system.file("shape/nc.shp", package="sf"), "nc", crs = 4267,
                  stringsAsFactors = FALSE, quiet = TRUE)
@@ -32,7 +47,7 @@ test_that("guess_driver works on extensions", {
   # for repeatability, this is how I turned the list to tests
   # `^"(\w+)" = ("[\w\s]+"),?`
   # to `expect_equal(guess_driver("nc.\1"), c("\1" = \2))`
-  
+
   expect_equal(guess_driver("nc.bna"), c("bna" = "BNA"))
   expect_equal(guess_driver("nc.csv"), c("csv" = "CSV"))
   expect_equal(guess_driver("nc.e00"), c("e00" = "AVCE00"))
@@ -42,7 +57,7 @@ test_that("guess_driver works on extensions", {
   expect_equal(guess_driver("nc.gmt"), c("gmt" = "GMT"))
   expect_equal(guess_driver("nc.gpkg"), c("gpkg" = "GPKG"))
   expect_equal(guess_driver("nc.gps"), c("gps" = "GPSBabel"))
-  expect_equal(guess_driver("nc.gtm"), c("gtm" = "GPSTrackMaker"))   
+  expect_equal(guess_driver("nc.gtm"), c("gtm" = "GPSTrackMaker"))
   expect_equal(guess_driver("nc.gxt"), c("gxt" = "Geoconcept"))
   expect_equal(guess_driver("nc.kml"), c("kml" = "KML"))
   expect_equal(guess_driver("nc.jml"), c("jml" = "JML"))
@@ -57,7 +72,7 @@ test_that("guess_driver works on extensions", {
   expect_equal(guess_driver("nc.vdv"), c("vdv" = "VDV"))
   expect_equal(guess_driver("nc.xls"), c("xls" = "xls"))
   expect_equal(guess_driver("nc.xlsx"), c("xlsx" = "XLSX"))
-  
+
   # unsuported
   expect_equal(guess_driver("nc.notsupported"), NA)
 })
@@ -66,7 +81,7 @@ test_that("guess_driver works on suffixes", {
   # for repeatability, this is how I turned the list to tests
   # `^"(\w+)" = ("[\w\s]+"),?`
   # to `expect_equal(guess_driver("nc.\1"), c("\1" = \2))`
-  
+
   expect_equal(guess_driver("couchdb:nc"), c("couchdb" = "CouchDB"))
   expect_equal(guess_driver("db2odbc:nc"), c("db2odbc" = "DB2ODBC"))
   expect_equal(guess_driver("dods:nc"), c("dods" = "DODS"))
@@ -77,7 +92,7 @@ test_that("guess_driver works on suffixes", {
   expect_equal(guess_driver("odbc:nc"), c("odbc" = "ODBC"))
   expect_equal(guess_driver("pg:nc"), c("pg" = "PostgreSQL"))
   expect_equal(guess_driver("sde:nc"), c("sde" = "SDE"))
-  
+
   # upper case
   expect_equal(guess_driver("CouchDB:nc"), c("couchdb" = "CouchDB"))
   expect_equal(guess_driver("db2ODBC:nc"), c("db2odbc" = "DB2ODBC"))
@@ -89,7 +104,7 @@ test_that("guess_driver works on suffixes", {
   expect_equal(guess_driver("ODBC:nc"), c("odbc" = "ODBC"))
   expect_equal(guess_driver("PG:nc"), c("pg" = "PostgreSQL"))
   expect_equal(guess_driver("SDE:nc"), c("sde" = "SDE"))
-  
+
   # unsuported
   expect_equal(guess_driver("notsupported:nc"), NA)
 })
@@ -99,7 +114,7 @@ test_that("weird names are supported", {
   expect_equal(guess_driver("pg:nc.shp.e00"), c("pg" = "PostgreSQL"))
   expect_equal(guess_driver("nc.shp.e00"), c("e00" = "AVCE00"))
   expect_equal(guess_driver("couchdb:shp"), c("couchdb" = "CouchDB"))
-  
+
   expect_equal(guess_driver("notsupported:nc.shp"), NA)
   expect_equal(guess_driver("notsupported"), NA)
 })
@@ -109,7 +124,7 @@ test_that("driver utils work", {
   expect_true(is_driver_available("shp", data.frame(name = c("shp"))))
   expect_false(is_driver_available("shp", data.frame(name = c("x", "y", "z"))))
   expect_false(is_driver_available("shp", data.frame(name = c("x", "y", "z"))))
-  
+
   expect_error(is_driver_can("shp", data.frame(name = c("x", "y", "shp")), operation = "nothing"))
   expect_error(is_driver_can("shp", data.frame(name = c("x", "y")), operation = "nothing"))
   expect_true(is_driver_can("shp", data.frame(name = c("x", "y", "shp"), write = rep(TRUE, 3)), operation = "write"))
@@ -121,23 +136,23 @@ test_that("guess_driver_can_write", {
   expect_error(guess_driver_can_write("x.not", c("nothing" = "nothing")), "not available")
   expect_equal(guess_driver_can_write("x.csv"), c("csv" = "CSV"))
   expect_equal(guess_driver_can_write("c:/x.csv"), c("csv" = "CSV"))
-  
+
   expect_error(guess_driver_can_write("x.unsuported"), "Could not guess driver")
   expect_error(guess_driver_can_write("unsuported:x"), "Could not guess driver")
 })
 
-test_that("driver operations", {  
+test_that("driver operations", {
   # These tests are driver specifics to GDAL version and OS.
   expect_error(guess_driver_can_write("x.e00"), "cannot write")
   expect_error(guess_driver_can_write("x.gdb"), "cannot write")
-  
+
   expect_equal(guess_driver_can_write("x.geojson"), c("geojson" = "GeoJSON"))
   expect_equal(guess_driver_can_write("x.csv"), c("csv" = "CSV"))
   expect_equal(guess_driver_can_write("x.gml"), c("gml" = "GML"))
 })
 
 test_that("guess driver on windows with backslashes (#127)", {
-    expect_identical(guess_driver("c:\\Temp\\this.shp"), 
+    expect_identical(guess_driver("c:\\Temp\\this.shp"),
                      guess_driver("c:/Temp/this.shp"))
 })
 
@@ -160,12 +175,32 @@ test_that("we get a warning when not specifying one of multiple layers", {
 })
 
 test_that("reading non-spatial table works", {
-	skip_if_not(sf_extSoftVersion()[["GDAL"]] >= "2.2.0") # error on OSX for 2.1.3
-	
-	expect_warning(st_read(system.file("gpkg/nospatial.gpkg", package = "sf")),
-				   "no simple feature geometries present")
-	expect_is(st_read(system.file("gpkg/nospatial.gpkg", package = "sf")),
-			  "data.frame")
-	expect_is(read_sf(system.file("gpkg/nospatial.gpkg", package = "sf")),
-			  "tbl_df")
+    skip_if_not(sf_extSoftVersion()[["GDAL"]] >= "2.2.0") # error on OSX for 2.1.3
+
+    expect_warning(st_read(system.file("gpkg/nospatial.gpkg", package = "sf")),
+                   "no simple feature geometries present")
+    expect_warning(
+        expect_is(st_read(system.file("gpkg/nospatial.gpkg", package = "sf")),
+                  "data.frame"),
+        "no simple feature geometries"
+    )
+#   expect_warning(
+#       expect_is(read_sf(system.file("gpkg/nospatial.gpkg", package = "sf")),
+#             "tbl_df"),
+#       "no simple feature geometries"
+#   )
+})
+
+test_that("Missing data sources have useful error message (#967)", {
+	# write temporary file
+	x <- tempfile(fileext = ".kml")
+	cat("empty", file = x)
+
+	expect_error(st_read(tempfile(fileext = ".csv")), "The file doesn't seem to exist.")
+	expect_error(st_read("PG:host=wrong"), "Check connection parameters.")
+	expect_error(st_read(x), "The source could be corrupt or not supported.")
+	expect_error(st_read(""), "not an empty string.")
+
+	# delete temp file
+	file.remove(x)
 })
